document.write("<a href=\"document_write.html\">JS</a>");
document.write("<a href=\"http://example.com/http_document_write.html\">JS</a>");
document.write('<a href="http://example.com/http_document_write2.html">JS</a>');
document.write('<a href="http://example.com/http document write.html">JS</a>');
var link = "script_variable.html";
link = "http://example.com/http_script_variable.html";
link = "https://example.com/https_script_variable.html";
link = "ftp://example.com/ftp_script_variable.html";
link = "end_dir_script_variable/";
link = "/start_dir_script_variable";
link = "../relative_dir_script_variable";
link = "script_variable.png";
link = {
	blah1: "script_json.html",
	blah2: "http://example.com/http_script_json.html?a\u003db"
};
var size = "4.0";
var mimetype = 'image/png';
link = "horse dolphin";
link = "cat[]monkey";
link = "fish$dog"
link = "rabbit\\ferre\t"
link = '\u9'
